export const colorLegend = (selection, props) => {
  const { 
    colorScale,
    circleRadius,
    spacing,
    textOffset,
    backgroundRectWidth,
    onClick,
    selectedColorValue
  } = props;
 
  const backgroundRect = selection.selectAll("rect")
  			.data([null]);
  const n = spacing * colorScale.domain().length;
  backgroundRect.enter().append("rect")
  	.merge(backgroundRect)
  		.attr("x", -circleRadius * 1.2)
  		.attr("y", -circleRadius * 1.2)
  		.attr("rx", circleRadius)
  		.attr("width", backgroundRectWidth)
  		.attr("height", n + circleRadius * 0.3)
  		.attr("fill", "white")
  		.attr("opacity", 0.8);
  
  const groups = selection.selectAll(".tick") //Make sure this has to be .tick
  	.data(colorScale.domain());
  const groupsEnter = groups
  	.enter().append("g")
  		.attr("class", "tick");
  groupsEnter
    .merge(groups)
  		.attr("transform", (d, i) => 
          `translate(0, ${i * spacing})` 
        	)
  		.attr("opacity", d => 
        ( !selectedColorValue || d === selectedColorValue)
          ?	1
          : 0.2
          )  	
  		.on("click", d => onClick(
    		d === selectedColorValue
    			? null
    			: d
  			));
  groups.exit().remove();
    
  groupsEnter.append("circle") 
  	.merge(groups.select("circle"))
      .attr("fill", colorScale)    
    	.attr("r", circleRadius); 
  
  groupsEnter.append("text") 
  	.merge(groups.select("text"))
      .text(d => d)
  		.attr("x", textOffset)
  		.attr("dy", "0.32em");
};