import { 
  select,
  scaleOrdinal,
  schemeSpectral
} from "d3";

import { loadAndProcessData } from "./loadAndProcessData";
import { colorLegend } from "./colorLegend";
import { coroplethMap } from "./coroplethMap";

const svg = select("svg");
const coroplethMapG = svg.append("g");
const colorLegendG = svg.append("g")
		.attr("transform", `translate(50, 300)`);    

const colorScale = scaleOrdinal();
// const colorValue = d => d.properties.economy;
const colorValue = d => d.properties.economy;

let selectedColorValue;
let features;

const onClick = d => {
	selectedColorValue = d;
  render();
};

loadAndProcessData().then(countries => {
	features = countries.features; 
  render();
});

const render = () => {
	colorScale
    .domain(features.map(colorValue))
  	.domain(colorScale.domain().sort().reverse())
  	.range(schemeSpectral[colorScale.domain().length]);

  colorLegendG.call(colorLegend, {
      colorScale,
      circleRadius: 10,
  		spacing: 22,
  		textOffset: 30,
    	backgroundRectWidth:200,
    	onClick,
    	selectedColorValue
	});
  
	coroplethMapG.call(coroplethMap, {
  		features,
    	colorScale,
    	colorValue,
    	selectedColorValue
  });

};



// use d.name for name
// use d.iso_n3 for id

